# VidList

A python utility for generating a listing of all the videos in the subfolders so that you can watch them in browser.

# Installation

```
pip3 install vidlist
```

# Usage

### For generating vidlist.html

Navigate to the directory where the subdirectories containing video files are present, then run

```
vidlist
```

Now open the vidlist.html file in browser.